@@ -9,6 +9,10 @@ from GinVPN.AES import AES
 import socket, string, random, requests,threading, queue
 
 
+from requests.adapters import HTTPAdapter
+from requests.packages.urllib3.util.retry import Retry
+
+
 
 aes=None
 def format_response(r):
@@ -22,19 +26,24 @@ def format_response(r):
     return byte_string
 def make_request(req_type, req_url, headers_dict, req_body):
     r=None
-    if(req_type==b'GET'):
-        r = requests.get(req_url, data=req_body,headers=headers_dict)
-    elif(req_type==b'POST'):
-        r = requests.post(req_url, data=req_body,headers=headers_dict)
-    elif(req_type==b'HEAD'):
-        r = requests.head(req_url, headers=headers_dict)
-    elif(req_type==b'PUT'):
-        r = requests.put(req_url, data=req_body,headers=headers_dict)
-    elif(req_type==b'DELETE'):
-        r = requests.delete(req_url, data=req_body,headers=headers_dict)
-    elif(req_type==b'OPTIONS'):
-        r = requests.options(req_url, data=req_body,headers=headers_dict)
-    return r
+    print("making request")
+    try:
+        if(req_type==b'GET'):
+            r = requests.get(req_url, data=req_body,headers=headers_dict)
+        elif(req_type==b'POST'):
+            r = requests.post(req_url, data=req_body,headers=headers_dict)
+        elif(req_type==b'HEAD'):
+            r = requests.head(req_url, headers=headers_dict)
+        elif(req_type==b'PUT'):
+            r = requests.put(req_url, data=req_body,headers=headers_dict)
+        elif(req_type==b'DELETE'):
+            r = requests.delete(req_url, data=req_body,headers=headers_dict)
+        elif(req_type==b'OPTIONS'):
+            r = requests.options(req_url, data=req_body,headers=headers_dict)
+        print("done with request")
+    except Exception as e:
+        return r,e
+    return r,''
 async def recv_msg(request):
     msg=await request.read()
     req=aes.decrypt(msg)
@@ -47,13 +56,13 @@ async def recv_msg(request):
     headers_dict={}
     for h in req_headers:
         headers_dict[h.split(b':')[0]]=h.split(b':')[1]
-    r=make_request(req_type, req_url, headers_dict, req_body)
-    b=aes.encrypt(format_response(r),False)
-    print(len(b))
+    r,e=make_request(req_type, req_url, headers_dict, req_body)
     if r!=None:
+        b=aes.encrypt(format_response(r),False)
+        print(len(b))
         return web.Response(status=200,body=bytes(b), headers={'zander-approved':'yes', 'Content-Length':str(len(b))})
     else:
-        return web.Response(status=500,text="Server Error", headers={'zander-approved':'yes'})
+        return web.Response(status=500,text=str(e))
 
     #return web.Response(status=500, text='GinVPN has encountered an error')
         
